import { INode } from './nodes/AbstractNode';
import { Path } from './model/Path';
export interface Registry<T> {
    register(id: string, value: T): void;
    get(id: string): T;
}
/**
 * Registry for schemas
 */
export declare class SchemaRegistry implements Registry<INode<any>> {
    private registry;
    register(id: string, node: INode<any>): void;
    get(id: string): INode<any>;
}
/**
 * Registry for collections
 */
export declare class CollectionRegistry implements Registry<string[]> {
    private registry;
    register(id: string, list: string[]): void;
    get(id: string): string[];
}
/**
 * Registry for locales
 */
export interface Locale {
    [key: string]: string;
}
export declare class LocaleRegistry implements Registry<Locale> {
    private registry;
    language: string;
    /**
     *
     * @param id locale identifier
     * @param locale object mapping keys to translations
     */
    register(id: string, locale: Locale): void;
    get(id: string): Locale;
    getLocale(key: string): string;
}
export declare const SCHEMAS: SchemaRegistry;
export declare const COLLECTIONS: CollectionRegistry;
export declare const LOCALES: LocaleRegistry;
/**
 * Gets the locale of a key from the locale registry.
 *
 * @param key string or path that refers to a locale ID.
 *    If a string is given, an exact match is required.
 *    If a path is given, it finds the longest match at the end.
 * @returns undefined if the key isn't found for the selected language
 */
export declare const locale: (key: string | Path) => string;
