"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.locale = exports.LOCALES = exports.COLLECTIONS = exports.SCHEMAS = exports.LocaleRegistry = exports.CollectionRegistry = exports.SchemaRegistry = void 0;
/**
 * Registry for schemas
 */
class SchemaRegistry {
    constructor() {
        this.registry = {};
    }
    register(id, node) {
        this.registry[id] = node;
    }
    get(id) {
        const node = this.registry[id];
        if (node === undefined) {
            console.error(`Tried to access schema "${id}, but that doesn't exit.`);
        }
        return node;
    }
}
exports.SchemaRegistry = SchemaRegistry;
/**
 * Registry for collections
 */
class CollectionRegistry {
    constructor() {
        this.registry = {};
    }
    register(id, list) {
        this.registry[id] = list;
    }
    get(id) {
        const list = this.registry[id];
        if (list === undefined) {
            console.warn(`Tried to access collection "${id}", but that doesn't exist`);
        }
        return list !== null && list !== void 0 ? list : [];
    }
}
exports.CollectionRegistry = CollectionRegistry;
class LocaleRegistry {
    constructor() {
        this.registry = {};
        this.language = '';
    }
    /**
     *
     * @param id locale identifier
     * @param locale object mapping keys to translations
     */
    register(id, locale) {
        this.registry[id] = locale;
    }
    get(id) {
        const locale = this.registry[id];
        if (locale === undefined) {
            console.warn(`Tried to access locale "${id}", but that doesn't exist`);
        }
        return locale !== null && locale !== void 0 ? locale : [];
    }
    getLocale(key) {
        return this.get(this.language)[key];
    }
}
exports.LocaleRegistry = LocaleRegistry;
exports.SCHEMAS = new SchemaRegistry();
exports.COLLECTIONS = new CollectionRegistry();
exports.LOCALES = new LocaleRegistry();
/**
 * Gets the locale of a key from the locale registry.
 *
 * @param key string or path that refers to a locale ID.
 *    If a string is given, an exact match is required.
 *    If a path is given, it finds the longest match at the end.
 * @returns undefined if the key isn't found for the selected language
 */
exports.locale = (key) => {
    var _a;
    if (typeof key === 'string') {
        return (_a = exports.LOCALES.getLocale(key)) !== null && _a !== void 0 ? _a : key;
    }
    let path = key.getArray().filter(e => (typeof e === 'string'));
    while (path.length > 0) {
        const locale = exports.LOCALES.getLocale(path.join('.'));
        if (locale !== undefined)
            return locale;
        path.shift();
    }
    return key.last().toString();
};
