"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RangeNode = void 0;
const AbstractNode_1 = require("../../nodes/AbstractNode");
const Registries_1 = require("../../Registries");
class RangeNode extends AbstractNode_1.AbstractNode {
    constructor(mods) {
        super(mods);
        this.integer = (mods === null || mods === void 0 ? void 0 : mods.integer) ? mods.integer : false;
    }
    parseNumber(str) {
        return this.integer ? parseInt(str) : parseFloat(str);
    }
    getState(el) {
        const type = el.querySelector('select').value;
        if (type === 'exact') {
            return this.parseNumber(el.querySelector('input').value);
        }
        if (type === 'range') {
            const min = this.parseNumber(el.querySelectorAll('input')[0].value);
            const max = this.parseNumber(el.querySelectorAll('input')[1].value);
            return {
                min: isNaN(min) ? undefined : min,
                max: isNaN(max) ? undefined : max
            };
        }
        const n = parseInt(el.querySelectorAll('input')[0].value);
        const p = parseFloat(el.querySelectorAll('input')[1].value);
        return {
            type: 'binomial',
            n: isNaN(n) ? undefined : n,
            p: isNaN(p) ? undefined : p
        };
    }
    render(path, value, view, options) {
        let curType = '';
        let input = '';
        if (value === undefined || typeof value === 'number') {
            curType = 'exact';
            input = `<input value=${value === undefined ? '' : value}>`;
        }
        else if (value.type === 'binomial') {
            curType = 'binomial';
            input = `<label>${Registries_1.locale('range.n')}</label>
        <input value=${value.n === undefined ? '' : value.n}>
        <label>${Registries_1.locale('range.p')}</label>
        <input value=${value.p === undefined ? '' : value.p}>`;
        }
        else {
            curType = 'range';
            input = `<label>${Registries_1.locale('range.min')}</label>
        <input value=${value.min === undefined ? '' : value.min}>
        <label>${Registries_1.locale('range.max')}</label>
        <input value=${value.max === undefined ? '' : value.max}>`;
        }
        const id = view.registerChange(el => {
            view.model.set(path, this.getState(el));
        });
        const selectId = view.register(el => {
            el.value = curType;
            el.addEventListener('change', evt => {
                const target = el.value;
                const newValue = this.default(target === 'exact' ? undefined :
                    target === 'binomial' ? { type: 'binomial' } : {});
                view.model.set(path, newValue);
                evt.stopPropagation();
            });
        });
        return `<div class="node range-node node-header" data-id="${id}">
      ${(options === null || options === void 0 ? void 0 : options.hideLabel) ? `` : `<label>${Registries_1.locale(path)}</label>`}
      <select data-id="${selectId}">
        <option value="exact">${Registries_1.locale('range.exact')}</option>
        <option value="range">${Registries_1.locale('range.range')}</option>
        <option value="binomial">${Registries_1.locale('range.binomial')}</option>
      </select>
      ${input}
    </div>`;
    }
    static isExact(v) {
        return v === undefined || typeof v === 'number';
    }
    static isRange(v) {
        return v !== undefined && typeof v !== 'number' && v.type !== 'binomial';
    }
    static isBinomial(v) {
        return v !== undefined && typeof v !== 'number' && v.type === 'binomial';
    }
}
exports.RangeNode = RangeNode;
