"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ResourceNode = void 0;
const EnumNode_1 = require("../../nodes/EnumNode");
const TreeView_1 = require("../../view/TreeView");
const Registries_1 = require("../../Registries");
class ResourceNode extends EnumNode_1.EnumNode {
    constructor(options, mods) {
        var _a;
        super(options, {
            transform: (v) => {
                if (v === undefined || v.length === 0)
                    return undefined;
                return v.startsWith('minecraft:') ? v : 'minecraft:' + v;
            }, ...mods
        });
        this.additional = (_a = mods === null || mods === void 0 ? void 0 : mods.additional) !== null && _a !== void 0 ? _a : false;
    }
    getState(el) {
        if (this.additional) {
            return el.value;
        }
        else {
            return super.getState(el);
        }
    }
    render(path, value, view, options) {
        if (this.additional) {
            const inputId = view.register(el => {
                el.value = value !== null && value !== void 0 ? value : '';
                el.addEventListener('change', evt => {
                    view.model.set(path, this.getState(el));
                    evt.stopPropagation();
                });
            });
            const id = `datalist-${TreeView_1.getId()}`;
            return `<div class="node node-header">
        ${(options === null || options === void 0 ? void 0 : options.hideLabel) ? `` : `<label>${Registries_1.locale(path)}</label>`}
        <input list=${id} data-id="${inputId}" value="${value !== null && value !== void 0 ? value : ''}">
        <datalist id=${id}>${this.options.map(o => `<option value="${o}">${Registries_1.locale(path.push(o))}</option>`).join('')}</datalist>
      </div>`;
        }
        else {
            return super.render(path, value, view, options);
        }
    }
}
exports.ResourceNode = ResourceNode;
