"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AdvancementSchema = void 0;
const EnumNode_1 = require("../../nodes/EnumNode");
const ResourceNode_1 = require("../nodes/ResourceNode");
const NumberNode_1 = require("../../nodes/NumberNode");
const BooleanNode_1 = require("../../nodes/BooleanNode");
const ObjectNode_1 = require("../../nodes/ObjectNode");
const ListNode_1 = require("../../nodes/ListNode");
const RangeNode_1 = require("../nodes/RangeNode");
const MapNode_1 = require("../../nodes/MapNode");
const StringNode_1 = require("../../nodes/StringNode");
const ReferenceNode_1 = require("../../nodes/ReferenceNode");
const JsonNode_1 = require("../nodes/JsonNode");
const Registries_1 = require("../../Registries");
require("./Predicates");
Registries_1.SCHEMAS.register('advancement', new ObjectNode_1.ObjectNode({
    display: new ObjectNode_1.ObjectNode({
        icon: new ObjectNode_1.ObjectNode({
            item: new ResourceNode_1.ResourceNode(Registries_1.COLLECTIONS.get('items')),
            nbt: new StringNode_1.StringNode()
        }),
        title: new JsonNode_1.JsonNode(),
        description: new JsonNode_1.JsonNode(),
        background: new StringNode_1.StringNode(),
        frame: new EnumNode_1.EnumNode(['task', 'challenge', 'goal']),
        show_toast: new BooleanNode_1.BooleanNode(),
        announce_to_chat: new BooleanNode_1.BooleanNode(),
        hidden: new BooleanNode_1.BooleanNode()
    }, { collapse: true }),
    parent: new StringNode_1.StringNode(),
    criteria: new MapNode_1.MapNode(new StringNode_1.StringNode(), new ReferenceNode_1.ReferenceNode('advancement-criteria')),
    rewards: new ObjectNode_1.ObjectNode({
        function: new StringNode_1.StringNode(),
        loot: new StringNode_1.StringNode(),
        recipes: new ListNode_1.ListNode(new StringNode_1.StringNode()),
        experience: new NumberNode_1.NumberNode({ integer: true })
    }, { collapse: true }),
}, {
    default: () => ({
        criteria: {
            requirement: {
                trigger: 'location'
            }
        }
    })
}));
Registries_1.SCHEMAS.register('advancement-criteria', new ObjectNode_1.ObjectNode({
    trigger: new ResourceNode_1.ResourceNode(Registries_1.COLLECTIONS.get('advancement-triggers')),
    conditions: new ObjectNode_1.ObjectNode({
        player: new ReferenceNode_1.ReferenceNode('entity-predicate', {
            collapse: true,
            enable: path => path.push('trigger').get() !== 'impossible'
        }),
        [ObjectNode_1.Switch]: path => path.pop().push('trigger').get(),
        [ObjectNode_1.Case]: {
            'bee_nest_destroyed': {
                block: new ResourceNode_1.ResourceNode(Registries_1.COLLECTIONS.get('blocks')),
                num_bees_inside: new NumberNode_1.NumberNode({ integer: true }),
                item: new ReferenceNode_1.ReferenceNode('item-predicate', { collapse: true })
            },
            'bred_animals': {
                parent: new ReferenceNode_1.ReferenceNode('entity-predicate', { collapse: true }),
                partner: new ReferenceNode_1.ReferenceNode('entity-predicate', { collapse: true }),
                child: new ReferenceNode_1.ReferenceNode('entity-predicate', { collapse: true })
            },
            'brewed_potion': {
                potion: new StringNode_1.StringNode()
            },
            'changed_dimension': {
                from: new ResourceNode_1.ResourceNode(Registries_1.COLLECTIONS.get('dimensions')),
                to: new ResourceNode_1.ResourceNode(Registries_1.COLLECTIONS.get('dimensions'))
            },
            'channeled_lightning': {
                victims: new ListNode_1.ListNode(new ReferenceNode_1.ReferenceNode('entity-predicate'))
            },
            'construct_beacon': {
                level: new RangeNode_1.RangeNode()
            },
            'consume_item': {
                item: new ReferenceNode_1.ReferenceNode('item-predicate', { collapse: true })
            },
            'cured_zombie_villager': {
                villager: new ReferenceNode_1.ReferenceNode('entity-predicate', { collapse: true }),
                zombie: new ReferenceNode_1.ReferenceNode('entity-predicate', { collapse: true })
            },
            'effects_changed': {
                effects: new MapNode_1.MapNode(new EnumNode_1.EnumNode(Registries_1.COLLECTIONS.get('status-effects')), new ObjectNode_1.ObjectNode({
                    amplifier: new RangeNode_1.RangeNode(),
                    duration: new RangeNode_1.RangeNode()
                }))
            },
            'enter_block': {
                block: new ResourceNode_1.ResourceNode(Registries_1.COLLECTIONS.get('blocks')),
                state: new MapNode_1.MapNode(new StringNode_1.StringNode(), new StringNode_1.StringNode())
            },
            'enchanted_item': {
                levels: new RangeNode_1.RangeNode(),
                item: new ReferenceNode_1.ReferenceNode('item-predicate', { collapse: true })
            },
            'entity_hurt_player': {
                entity: new ReferenceNode_1.ReferenceNode('entity-predicate', { collapse: true }),
                damage: new ReferenceNode_1.ReferenceNode('damage-predicate', { collapse: true })
            },
            'entity_killed_player': {
                entity: new ReferenceNode_1.ReferenceNode('entity-predicate', { collapse: true }),
                killing_blow: new ReferenceNode_1.ReferenceNode('damage-source-predicate', { collapse: true })
            },
            'filled_bucket': {
                item: new ReferenceNode_1.ReferenceNode('item-predicate', { collapse: true })
            },
            'fishing_rod_hooked': {
                entity: new ReferenceNode_1.ReferenceNode('entity-predicate', { collapse: true }),
                item: new ReferenceNode_1.ReferenceNode('item-predicate', { collapse: true })
            },
            'hero_of_the_village': {
                location: new ReferenceNode_1.ReferenceNode('location-predicate', { collapse: true })
            },
            'inventory_changed': {
                slots: new ObjectNode_1.ObjectNode({
                    empty: new RangeNode_1.RangeNode(),
                    occupied: new RangeNode_1.RangeNode(),
                    fill: new RangeNode_1.RangeNode()
                }),
                items: new ListNode_1.ListNode(new ReferenceNode_1.ReferenceNode('item-predicate'))
            },
            'item_durability_changed': {
                delta: new RangeNode_1.RangeNode(),
                durability: new RangeNode_1.RangeNode(),
                item: new ReferenceNode_1.ReferenceNode('item-predicate', { collapse: true })
            },
            'item_used_on_block': {
                item: new ReferenceNode_1.ReferenceNode('item-predicate', { collapse: true }),
                location: new ReferenceNode_1.ReferenceNode('location-predicate', { collapse: true })
            },
            'killed_by_crossbow': {
                unique_entity_types: new RangeNode_1.RangeNode(),
                victims: new ListNode_1.ListNode(new ReferenceNode_1.ReferenceNode('entity-predicate'))
            },
            'levitation': {
                distance: new RangeNode_1.RangeNode(),
                duration: new RangeNode_1.RangeNode()
            },
            'location': {
                location: new ReferenceNode_1.ReferenceNode('location-predicate', { collapse: true })
            },
            'nether_travel': {
                distance: new RangeNode_1.RangeNode()
            },
            'placed_block': {
                block: new ResourceNode_1.ResourceNode(Registries_1.COLLECTIONS.get('blocks')),
                state: new MapNode_1.MapNode(new StringNode_1.StringNode(), new StringNode_1.StringNode()),
                item: new ReferenceNode_1.ReferenceNode('item-predicate', { collapse: true }),
                location: new ReferenceNode_1.ReferenceNode('location-predicate', { collapse: true })
            },
            'player_generates_container_loot': {
                loot_table: new StringNode_1.StringNode()
            },
            'player_hurt_entity': {
                damage: new ReferenceNode_1.ReferenceNode('damage-predicate', { collapse: true }),
                entity: new ReferenceNode_1.ReferenceNode('entity-predicate', { collapse: true })
            },
            'player_killed_player': {
                killing_blow: new ReferenceNode_1.ReferenceNode('damage-source-predicate', { collapse: true })
            },
            'recipe_unlocked': {
                recipe: new StringNode_1.StringNode()
            },
            'slept_in_bed': {
                location: new ReferenceNode_1.ReferenceNode('location-predicate', { collapse: true })
            },
            'slide_down_block': {
                block: new ResourceNode_1.ResourceNode(Registries_1.COLLECTIONS.get('blocks'))
            },
            'shot_crossbow': {
                item: new ReferenceNode_1.ReferenceNode('item-predicate', { collapse: true })
            },
            'summoned_entity': {
                entity: new ReferenceNode_1.ReferenceNode('entity-predicate', { collapse: true })
            },
            'tame_animal': {
                entity: new ReferenceNode_1.ReferenceNode('entity-predicate', { collapse: true })
            },
            'thrown_item_picked_up_by_entity': {
                entity: new ReferenceNode_1.ReferenceNode('entity-predicate', { collapse: true }),
                item: new ReferenceNode_1.ReferenceNode('item-predicate', { collapse: true })
            },
            'used_ender_eye': {
                distance: new RangeNode_1.RangeNode()
            },
            'used_totem': {
                item: new ReferenceNode_1.ReferenceNode('item-predicate', { collapse: true })
            },
            'villager_trade': {
                item: new ReferenceNode_1.ReferenceNode('item-predicate', { collapse: true })
            },
            'voluntary_exile': {
                location: new ReferenceNode_1.ReferenceNode('location-predicate', { collapse: true })
            }
        }
    })
}, {
    category: 'predicate'
}));
exports.AdvancementSchema = Registries_1.SCHEMAS.get('advancement');
