"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DimensionTypeSchema = exports.DimensionSchema = void 0;
const EnumNode_1 = require("../../nodes/EnumNode");
const ResourceNode_1 = require("../nodes/ResourceNode");
const NumberNode_1 = require("../../nodes/NumberNode");
const BooleanNode_1 = require("../../nodes/BooleanNode");
const ObjectNode_1 = require("../../nodes/ObjectNode");
const ListNode_1 = require("../../nodes/ListNode");
const MapNode_1 = require("../../nodes/MapNode");
const StringNode_1 = require("../../nodes/StringNode");
const ReferenceNode_1 = require("../../nodes/ReferenceNode");
const Registries_1 = require("../../Registries");
Registries_1.SCHEMAS.register('dimension', new ObjectNode_1.ObjectNode({
    type: new StringNode_1.StringNode(),
    generator: new ObjectNode_1.ObjectNode({
        type: new EnumNode_1.EnumNode(['noise', 'flat', 'debug']),
        seed: new NumberNode_1.NumberNode({ integer: true }),
        [ObjectNode_1.Switch]: path => path.push('type').get(),
        [ObjectNode_1.Case]: {
            'noise': {
                biome_source: new ObjectNode_1.ObjectNode({
                    type: new EnumNode_1.EnumNode(['fixed', 'multi_noise', 'checkerboard', 'vanilla_layered', 'the_end']),
                    seed: new NumberNode_1.NumberNode({ integer: true }),
                    [ObjectNode_1.Switch]: path => path.push('type').get(),
                    [ObjectNode_1.Case]: {
                        'fixed': {
                            biome: new EnumNode_1.EnumNode(Registries_1.COLLECTIONS.get('biomes'))
                        },
                        'multi_noise': {
                            preset: new EnumNode_1.EnumNode(['nether']),
                            biomes: new ListNode_1.ListNode(new ReferenceNode_1.ReferenceNode('generator-biome'))
                        },
                        'checkerboard': {
                            biomes: new ListNode_1.ListNode(new EnumNode_1.EnumNode(Registries_1.COLLECTIONS.get('biomes')))
                        },
                        'vanilla_layered': {
                            large_biomes: new BooleanNode_1.BooleanNode()
                        }
                    }
                }, {
                    category: 'predicate'
                }),
                settings: new ObjectNode_1.ObjectNode({
                    bedrock_roof_position: new NumberNode_1.NumberNode({ integer: true }),
                    bedrock_floor_position: new NumberNode_1.NumberNode({ integer: true }),
                    sea_level: new NumberNode_1.NumberNode({ integer: true }),
                    disable_mob_generation: new BooleanNode_1.BooleanNode(),
                    default_block: new ObjectNode_1.ObjectNode({
                        Name: new StringNode_1.StringNode(),
                        Properties: new MapNode_1.MapNode(new StringNode_1.StringNode(), new StringNode_1.StringNode())
                    }),
                    default_fluid: new ObjectNode_1.ObjectNode({
                        Name: new StringNode_1.StringNode(),
                        Properties: new MapNode_1.MapNode(new StringNode_1.StringNode(), new StringNode_1.StringNode({ default: () => "" }))
                    }),
                    noise: new ObjectNode_1.ObjectNode({
                        density_factor: new NumberNode_1.NumberNode(),
                        density_offset: new NumberNode_1.NumberNode(),
                        simplex_surface_noise: new BooleanNode_1.BooleanNode(),
                        random_density_offset: new BooleanNode_1.BooleanNode(),
                        island_noise_override: new BooleanNode_1.BooleanNode(),
                        amplified: new BooleanNode_1.BooleanNode(),
                        size_horizontal: new NumberNode_1.NumberNode({ integer: true }),
                        size_vertical: new NumberNode_1.NumberNode({ integer: true }),
                        height: new NumberNode_1.NumberNode({ integer: true }),
                        sampling: new ObjectNode_1.ObjectNode({
                            xz_scale: new NumberNode_1.NumberNode(),
                            y_scale: new NumberNode_1.NumberNode(),
                            xz_factor: new NumberNode_1.NumberNode(),
                            y_factor: new NumberNode_1.NumberNode()
                        }),
                        bottom_slide: new ObjectNode_1.ObjectNode({
                            target: new NumberNode_1.NumberNode({ integer: true }),
                            size: new NumberNode_1.NumberNode({ integer: true }),
                            offset: new NumberNode_1.NumberNode({ integer: true })
                        }),
                        top_slide: new ObjectNode_1.ObjectNode({
                            target: new NumberNode_1.NumberNode({ integer: true }),
                            size: new NumberNode_1.NumberNode({ integer: true }),
                            offset: new NumberNode_1.NumberNode({ integer: true })
                        })
                    }, { collapse: true }),
                    structures: new ReferenceNode_1.ReferenceNode('generator-structures')
                }, { collapse: true })
            },
            'flat': {
                settings: new ObjectNode_1.ObjectNode({
                    biome: new EnumNode_1.EnumNode(Registries_1.COLLECTIONS.get('biomes')),
                    layers: new ListNode_1.ListNode(new ReferenceNode_1.ReferenceNode('generator-layer')),
                    structures: new ReferenceNode_1.ReferenceNode('generator-structures')
                }, { collapse: true })
            }
        }
    })
}, {
    default: () => ({
        generator: {
            type: 'noise',
            seed: 0,
            biome_source: {
                type: 'multi_noise',
                seed: 0
            }
        }
    })
}));
Registries_1.SCHEMAS.register('generator-biome', new ObjectNode_1.ObjectNode({
    biome: new EnumNode_1.EnumNode(Registries_1.COLLECTIONS.get('biomes')),
    parameters: new ObjectNode_1.ObjectNode({
        altitude: new NumberNode_1.NumberNode(),
        temperature: new NumberNode_1.NumberNode(),
        humidity: new NumberNode_1.NumberNode(),
        weirdness: new NumberNode_1.NumberNode(),
        offset: new NumberNode_1.NumberNode()
    })
}, {
    default: () => ({
        biome: 'plains',
        parameters: {
            altitude: 0,
            temperature: 0,
            humidity: 0,
            weirdness: 0,
            offset: 0
        }
    })
}));
Registries_1.SCHEMAS.register('generator-structures', new ObjectNode_1.ObjectNode({
    stronghold: new ObjectNode_1.ObjectNode({
        distance: new NumberNode_1.NumberNode({ integer: true }),
        spread: new NumberNode_1.NumberNode({ integer: true }),
        count: new NumberNode_1.NumberNode({ integer: true })
    }, {
        collapse: true
    }),
    structures: new MapNode_1.MapNode(new EnumNode_1.EnumNode(Registries_1.COLLECTIONS.get('structures')), new ObjectNode_1.ObjectNode({
        spacing: new NumberNode_1.NumberNode({ integer: true }),
        separation: new NumberNode_1.NumberNode({ integer: true }),
        salt: new NumberNode_1.NumberNode({ integer: true })
    }, {
        default: () => ({
            spacing: 10,
            separation: 5,
            salt: 0
        })
    }))
}));
Registries_1.SCHEMAS.register('generator-layer', new ObjectNode_1.ObjectNode({
    block: new ResourceNode_1.ResourceNode(Registries_1.COLLECTIONS.get('blocks')),
    height: new NumberNode_1.NumberNode({ integer: true })
}, {
    default: () => ({
        block: 'stone',
        height: 1
    })
}));
Registries_1.SCHEMAS.register('dimension-type', new ObjectNode_1.ObjectNode({
    ultrawarm: new BooleanNode_1.BooleanNode(),
    natural: new BooleanNode_1.BooleanNode(),
    shrunk: new BooleanNode_1.BooleanNode(),
    ambient_light: new NumberNode_1.NumberNode(),
    fixed_time: new NumberNode_1.NumberNode({ integer: true }),
    has_skylight: new BooleanNode_1.BooleanNode(),
    has_ceiling: new BooleanNode_1.BooleanNode()
}, {
    default: () => ({
        ultrawarm: false,
        natural: true,
        shrunk: false,
        ambient_light: 0,
        has_skylight: true,
        has_ceiling: false
    })
}));
exports.DimensionSchema = Registries_1.SCHEMAS.get('dimension');
exports.DimensionTypeSchema = Registries_1.SCHEMAS.get('dimension-type');
