"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LootTableSchema = void 0;
const EnumNode_1 = require("../../nodes/EnumNode");
const ResourceNode_1 = require("../nodes/ResourceNode");
const NumberNode_1 = require("../../nodes/NumberNode");
const BooleanNode_1 = require("../../nodes/BooleanNode");
const ObjectNode_1 = require("../../nodes/ObjectNode");
const ListNode_1 = require("../../nodes/ListNode");
const RangeNode_1 = require("../nodes/RangeNode");
const StringNode_1 = require("../../nodes/StringNode");
const ReferenceNode_1 = require("../../nodes/ReferenceNode");
const JsonNode_1 = require("../nodes/JsonNode");
const Registries_1 = require("../../Registries");
require("./Condition");
const conditions = {
    conditions: new ListNode_1.ListNode(new ReferenceNode_1.ReferenceNode('condition'))
};
const functionsAndConditions = {
    functions: new ListNode_1.ListNode(new ReferenceNode_1.ReferenceNode('loot-function')),
    ...conditions
};
Registries_1.SCHEMAS.register('loot-table', new ObjectNode_1.ObjectNode({
    pools: new ListNode_1.ListNode(new ObjectNode_1.ObjectNode({
        rolls: new RangeNode_1.RangeNode(),
        entries: new ListNode_1.ListNode(new ReferenceNode_1.ReferenceNode('loot-entry')),
        ...functionsAndConditions
    })),
    ...functionsAndConditions
}, {
    default: () => ({
        pools: [
            {
                rolls: 1,
                entries: [
                    {
                        type: 'item',
                        name: 'minecraft:stone'
                    }
                ]
            }
        ]
    })
}));
Registries_1.SCHEMAS.register('loot-entry', new ObjectNode_1.ObjectNode({
    type: new EnumNode_1.EnumNode(Registries_1.COLLECTIONS.get('loot-entries'), { default: () => 'item' }),
    weight: new NumberNode_1.NumberNode({
        integer: true,
        min: 1,
        enable: path => {
            var _a;
            return ((_a = path.pop().get()) === null || _a === void 0 ? void 0 : _a.length) > 1
                && !['alternatives', 'group', 'sequence'].includes(path.push('type').get());
        }
    }),
    [ObjectNode_1.Switch]: path => path.push('type').get(),
    [ObjectNode_1.Case]: {
        'alternatives': {
            children: new ListNode_1.ListNode(new ReferenceNode_1.ReferenceNode('loot-entry')),
            ...functionsAndConditions
        },
        'dynamic': {
            name: new StringNode_1.StringNode(),
            ...functionsAndConditions
        },
        'group': {
            children: new ListNode_1.ListNode(new ReferenceNode_1.ReferenceNode('loot-entry')),
            ...functionsAndConditions
        },
        'item': {
            name: new StringNode_1.StringNode(),
            ...functionsAndConditions
        },
        'loot_table': {
            name: new StringNode_1.StringNode(),
            ...functionsAndConditions
        },
        'sequence': {
            children: new ListNode_1.ListNode(new ReferenceNode_1.ReferenceNode('loot-entry')),
            ...functionsAndConditions
        },
        'tag': {
            name: new StringNode_1.StringNode(),
            expand: new BooleanNode_1.BooleanNode(),
            ...functionsAndConditions
        }
    }
}));
Registries_1.SCHEMAS.register('loot-function', new ObjectNode_1.ObjectNode({
    function: new EnumNode_1.EnumNode(Registries_1.COLLECTIONS.get('loot-functions'), { default: () => 'set_count' }),
    [ObjectNode_1.Switch]: path => path.push('function').get(),
    [ObjectNode_1.Case]: {
        'apply_bonus': {
            enchantment: new EnumNode_1.EnumNode(Registries_1.COLLECTIONS.get('enchantments')),
            formula: new EnumNode_1.EnumNode([
                'uniform_bonus_count',
                'binomial_with_bonus_count',
                'ore_drops'
            ]),
            parameters: new ObjectNode_1.ObjectNode({
                bonusMultiplier: new NumberNode_1.NumberNode({
                    enable: path => path.pop().push('formula').get() === 'uniform_bonus_count'
                }),
                extra: new NumberNode_1.NumberNode({
                    enable: path => path.pop().push('formula').get() === 'binomial_with_bonus_count'
                }),
                probability: new NumberNode_1.NumberNode({
                    enable: path => path.pop().push('formula').get() === 'binomial_with_bonus_count'
                })
            }, {
                enable: path => path.push('formula').get() !== 'ore_drops'
            }),
            ...conditions
        },
        'copy_name': {
            source: new EnumNode_1.EnumNode(Registries_1.COLLECTIONS.get('copy-sources')),
            ...conditions
        },
        'copy_nbt': {
            source: new EnumNode_1.EnumNode(Registries_1.COLLECTIONS.get('copy-sources')),
            ops: new ListNode_1.ListNode(new ObjectNode_1.ObjectNode({
                source: new StringNode_1.StringNode(),
                target: new StringNode_1.StringNode(),
                op: new EnumNode_1.EnumNode(['replace', 'append', 'merge'])
            })),
            ...conditions
        },
        'copy_state': {
            block: new ResourceNode_1.ResourceNode(Registries_1.COLLECTIONS.get('blocks')),
            properties: new ListNode_1.ListNode(new StringNode_1.StringNode()),
            ...conditions
        },
        'enchant_randomly': {
            enchantments: new ListNode_1.ListNode(new EnumNode_1.EnumNode(Registries_1.COLLECTIONS.get('enchantments'))),
            ...conditions
        },
        'enchant_with_levels': {
            levels: new RangeNode_1.RangeNode(),
            treasure: new BooleanNode_1.BooleanNode(),
            ...conditions
        },
        'exploration_map': {
            destination: new EnumNode_1.EnumNode(Registries_1.COLLECTIONS.get('structures')),
            decoration: new EnumNode_1.EnumNode(Registries_1.COLLECTIONS.get('map-decorations')),
            zoom: new NumberNode_1.NumberNode({ integer: true }),
            search_radius: new NumberNode_1.NumberNode({ integer: true }),
            skip_existing_chunks: new BooleanNode_1.BooleanNode(),
            ...conditions
        },
        'fill_player_head': {
            entity: new EnumNode_1.EnumNode(Registries_1.COLLECTIONS.get('entity-sources')),
            ...conditions
        },
        'limit_count': {
            limit: new RangeNode_1.RangeNode(),
            ...conditions
        },
        'looting_enchant': {
            count: new RangeNode_1.RangeNode(),
            limit: new NumberNode_1.NumberNode({ integer: true }),
            ...conditions
        },
        'set_attributes': {
            modifiers: new ListNode_1.ListNode(new ReferenceNode_1.ReferenceNode('attribute-modifier')),
            ...conditions
        },
        'set_contents': {
            entries: new ListNode_1.ListNode(new ReferenceNode_1.ReferenceNode('loot-entry')),
            ...conditions
        },
        'set_count': {
            count: new RangeNode_1.RangeNode(),
            ...conditions
        },
        'set_damage': {
            damage: new RangeNode_1.RangeNode(),
            ...conditions
        },
        'set_lore': {
            entity: new EnumNode_1.EnumNode(Registries_1.COLLECTIONS.get('entity-sources')),
            lore: new ListNode_1.ListNode(new JsonNode_1.JsonNode()),
            replace: new BooleanNode_1.BooleanNode(),
            ...conditions
        },
        'set_name': {
            entity: new EnumNode_1.EnumNode(Registries_1.COLLECTIONS.get('entity-sources')),
            name: new JsonNode_1.JsonNode(),
            ...conditions
        },
        'set_nbt': {
            tag: new StringNode_1.StringNode(),
            ...conditions
        },
        'set_stew_effect': {
            effects: new ListNode_1.ListNode(new ObjectNode_1.ObjectNode({
                type: new StringNode_1.StringNode(),
                duration: new RangeNode_1.RangeNode()
            })),
            ...conditions
        }
    }
}, {
    category: 'function',
    default: () => ({
        function: 'set_count',
        count: 1
    })
}));
Registries_1.SCHEMAS.register('attribute-modifier', new ObjectNode_1.ObjectNode({
    attribute: new EnumNode_1.EnumNode(Registries_1.COLLECTIONS.get('attributes')),
    name: new StringNode_1.StringNode(),
    amount: new RangeNode_1.RangeNode(),
    operation: new EnumNode_1.EnumNode([
        'addition',
        'multiply_base',
        'multiply_total'
    ]),
    slot: new ListNode_1.ListNode(new EnumNode_1.EnumNode(Registries_1.COLLECTIONS.get('slots')))
}));
exports.LootTableSchema = Registries_1.SCHEMAS.get('loot-table');
