"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ObjectNode_1 = require("../../nodes/ObjectNode");
const ResourceNode_1 = require("../nodes/ResourceNode");
const EnumNode_1 = require("../../nodes/EnumNode");
const ListNode_1 = require("../../nodes/ListNode");
const RangeNode_1 = require("../nodes/RangeNode");
const StringNode_1 = require("../../nodes/StringNode");
const ReferenceNode_1 = require("../../nodes/ReferenceNode");
const BooleanNode_1 = require("../../nodes/BooleanNode");
const MapNode_1 = require("../../nodes/MapNode");
const Registries_1 = require("../../Registries");
require("./Collections");
Registries_1.SCHEMAS.register('item-predicate', new ObjectNode_1.ObjectNode({
    item: new ResourceNode_1.ResourceNode(Registries_1.COLLECTIONS.get('items')),
    tag: new StringNode_1.StringNode(),
    count: new RangeNode_1.RangeNode(),
    durability: new RangeNode_1.RangeNode(),
    potion: new StringNode_1.StringNode(),
    nbt: new StringNode_1.StringNode(),
    enchantments: new ListNode_1.ListNode(new ReferenceNode_1.ReferenceNode('enchantment-predicate'))
}));
Registries_1.SCHEMAS.register('enchantment-predicate', new ObjectNode_1.ObjectNode({
    enchantment: new ResourceNode_1.ResourceNode(Registries_1.COLLECTIONS.get('enchantments')),
    levels: new RangeNode_1.RangeNode()
}));
Registries_1.SCHEMAS.register('block-predicate', new ObjectNode_1.ObjectNode({
    block: new ResourceNode_1.ResourceNode(Registries_1.COLLECTIONS.get('blocks')),
    tag: new StringNode_1.StringNode(),
    nbt: new StringNode_1.StringNode(),
    state: new MapNode_1.MapNode(new StringNode_1.StringNode(), new StringNode_1.StringNode())
}));
Registries_1.SCHEMAS.register('fluid-predicate', new ObjectNode_1.ObjectNode({
    fluid: new ResourceNode_1.ResourceNode(Registries_1.COLLECTIONS.get('fluids')),
    tag: new StringNode_1.StringNode(),
    nbt: new StringNode_1.StringNode(),
    state: new MapNode_1.MapNode(new StringNode_1.StringNode(), new StringNode_1.StringNode())
}));
Registries_1.SCHEMAS.register('location-predicate', new ObjectNode_1.ObjectNode({
    position: new ObjectNode_1.ObjectNode({
        x: new RangeNode_1.RangeNode(),
        y: new RangeNode_1.RangeNode(),
        z: new RangeNode_1.RangeNode()
    }, { collapse: true }),
    biome: new ResourceNode_1.ResourceNode(Registries_1.COLLECTIONS.get('biomes')),
    feature: new EnumNode_1.EnumNode(Registries_1.COLLECTIONS.get('structures')),
    dimension: new ResourceNode_1.ResourceNode(Registries_1.COLLECTIONS.get('dimensions'), { additional: true }),
    light: new ObjectNode_1.ObjectNode({
        light: new RangeNode_1.RangeNode()
    }),
    smokey: new BooleanNode_1.BooleanNode(),
    block: new ReferenceNode_1.ReferenceNode('block-predicate', { collapse: true }),
    fluid: new ReferenceNode_1.ReferenceNode('fluid-predicate', { collapse: true })
}));
Registries_1.SCHEMAS.register('statistic-predicate', new ObjectNode_1.ObjectNode({
    type: new EnumNode_1.EnumNode(Registries_1.COLLECTIONS.get('statistic-types')),
    stat: new StringNode_1.StringNode(),
    value: new RangeNode_1.RangeNode()
}));
Registries_1.SCHEMAS.register('player-predicate', new ObjectNode_1.ObjectNode({
    gamemode: new EnumNode_1.EnumNode(Registries_1.COLLECTIONS.get('gamemodes')),
    level: new RangeNode_1.RangeNode(),
    advancements: new MapNode_1.MapNode(new StringNode_1.StringNode(), new BooleanNode_1.BooleanNode()),
    recipes: new MapNode_1.MapNode(new StringNode_1.StringNode(), new BooleanNode_1.BooleanNode()),
    stats: new ListNode_1.ListNode(new ReferenceNode_1.ReferenceNode('statistic-predicate'))
}));
Registries_1.SCHEMAS.register('status-effect-predicate', new ObjectNode_1.ObjectNode({
    amplifier: new RangeNode_1.RangeNode(),
    duration: new RangeNode_1.RangeNode(),
    ambient: new BooleanNode_1.BooleanNode(),
    visible: new BooleanNode_1.BooleanNode()
}));
Registries_1.SCHEMAS.register('distance-predicate', new ObjectNode_1.ObjectNode({
    x: new RangeNode_1.RangeNode(),
    y: new RangeNode_1.RangeNode(),
    z: new RangeNode_1.RangeNode(),
    absolute: new RangeNode_1.RangeNode(),
    horizontal: new RangeNode_1.RangeNode()
}));
Registries_1.SCHEMAS.register('entity-predicate', new ObjectNode_1.ObjectNode({
    type: new StringNode_1.StringNode(),
    nbt: new StringNode_1.StringNode(),
    team: new StringNode_1.StringNode(),
    location: new ReferenceNode_1.ReferenceNode('location-predicate', { collapse: true }),
    distance: new ReferenceNode_1.ReferenceNode('distance-predicate', { collapse: true }),
    flags: new ObjectNode_1.ObjectNode({
        is_on_fire: new BooleanNode_1.BooleanNode(),
        is_sneaking: new BooleanNode_1.BooleanNode(),
        is_sprinting: new BooleanNode_1.BooleanNode(),
        is_swimming: new BooleanNode_1.BooleanNode(),
        is_baby: new BooleanNode_1.BooleanNode()
    }, { collapse: true }),
    equipment: new MapNode_1.MapNode(new EnumNode_1.EnumNode(Registries_1.COLLECTIONS.get('slots')), new ReferenceNode_1.ReferenceNode('item-predicate')),
    vehicle: new ReferenceNode_1.ReferenceNode('entity-predicate', { collapse: true }),
    targeted_entity: new ReferenceNode_1.ReferenceNode('entity-predicate', { collapse: true }),
    player: new ReferenceNode_1.ReferenceNode('player-predicate', { collapse: true }),
    fishing_hook: new ObjectNode_1.ObjectNode({
        in_open_water: new BooleanNode_1.BooleanNode()
    }),
    effects: new MapNode_1.MapNode(new ResourceNode_1.ResourceNode(Registries_1.COLLECTIONS.get('status-effects')), new ReferenceNode_1.ReferenceNode('status-effect-predicate'))
}));
