import { Path } from './Path';
import { INode } from '../nodes/AbstractNode';
import { Errors } from './Errors';
export interface ModelListener {
    invalidated(model: DataModel): void;
}
/**
 * Holding the data linked to a given schema
 */
export declare class DataModel {
    data: any;
    schema: INode<any>;
    /** A list of listeners that want to be notified when the model is invalidated */
    listeners: ModelListener[];
    valid: boolean;
    /**
     * @param schema node to use as schema for this model
     */
    constructor(schema: INode<any>);
    /**
     * Adds a listener to notify when the model is invalidated
     * @param listener the listener to be notified
     */
    addListener(listener: ModelListener): void;
    /**
     * Removes a listener from this model
     * @param listener the listener to be removed
     */
    removeListener(listener: ModelListener): void;
    /**
     * Force notify all listeners that the model is invalidated
     */
    invalidate(): void;
    /**
     * Resets the full data and notifies listeners
     * @param value new model data
     */
    reset(value: any): void;
    /**
     * Gets the data at a specified path
     * @param path path at which to find the data
     * @returns undefined, if the the path does not exist in the data
     */
    get(path: Path): any;
    /**
     * Updates the date on a path. Node will be removed when value is undefined
     * @param path path to update
     * @param value new data at the specified path
     */
    set(path: Path, value: any): void;
    /**
     * Uses the schema to check whether the data is valid
     * @returns list of errors in case the data is invalid
     */
    validate(): Errors;
    /**
     * Whether the current data is valid according to the schema
     */
    isValid(): boolean;
}
