import { DataModel } from './DataModel';
export declare type PathElement = (string | number);
/**
 * Immutable helper class to represent a path in data
 * @implements {Iterable<PathElement>}
 */
export declare class Path implements Iterable<PathElement> {
    private arr;
    model?: DataModel;
    /**
     * @param arr Initial array of path elements. Empty if not given
     * @param model Model attached to this path
     */
    constructor(arr?: PathElement[], model?: DataModel);
    /**
     * The last element of this path
     */
    last(): PathElement;
    /**
     * A new path with the last element removed
     */
    pop(): Path;
    /**
     * A new path with an element added at the end
     * @param element element to push at the end of the array
     */
    push(element: PathElement): Path;
    copy(): Path;
    getArray(): PathElement[];
    /**
     * Attaches a model to this path and all paths created from this
     * @param model
     */
    withModel(model: DataModel): Path;
    getModel(): DataModel | undefined;
    /**
     * Gets the data from the model if it was attached
     * @returns undefined, if no model was attached
     */
    get(): any;
    /**
     * Sets the value to the model if it was attached
     */
    set(value: any): void;
    toString(): string;
    [Symbol.iterator](): Generator<PathElement, void, unknown>;
}
