"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Path = void 0;
/**
 * Immutable helper class to represent a path in data
 * @implements {Iterable<PathElement>}
 */
class Path {
    /**
     * @param arr Initial array of path elements. Empty if not given
     * @param model Model attached to this path
     */
    constructor(arr, model) {
        this.arr = arr !== null && arr !== void 0 ? arr : [];
        this.model = model;
    }
    /**
     * The last element of this path
     */
    last() {
        return this.arr[this.arr.length - 1];
    }
    /**
     * A new path with the last element removed
     */
    pop() {
        return new Path(this.arr.slice(0, -1), this.model);
    }
    /**
     * A new path with an element added at the end
     * @param element element to push at the end of the array
     */
    push(element) {
        return new Path([...this.arr, element], this.model);
    }
    copy() {
        return new Path([...this.arr], this.model);
    }
    getArray() {
        return this.arr;
    }
    /**
     * Attaches a model to this path and all paths created from this
     * @param model
     */
    withModel(model) {
        return new Path([...this.arr], model);
    }
    getModel() {
        return this.model;
    }
    /**
     * Gets the data from the model if it was attached
     * @returns undefined, if no model was attached
     */
    get() {
        var _a;
        return (_a = this.model) === null || _a === void 0 ? void 0 : _a.get(this);
    }
    /**
     * Sets the value to the model if it was attached
     */
    set(value) {
        var _a;
        (_a = this.model) === null || _a === void 0 ? void 0 : _a.set(this, value);
    }
    toString() {
        return `[${this.arr.map(e => e.toString()).join(', ')}]`;
    }
    *[Symbol.iterator]() {
        for (const e of this.arr) {
            yield e;
        }
    }
}
exports.Path = Path;
