"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AbstractNode = void 0;
/**
 * Basic implementation of the nodes
 */
class AbstractNode {
    /**
     * @param mods modifiers of the default transformations
     */
    constructor(mods) {
        var _a, _b, _c, _d;
        this.defaultMod = (_a = mods === null || mods === void 0 ? void 0 : mods.default) !== null && _a !== void 0 ? _a : ((v) => v);
        this.transformMod = (_b = mods === null || mods === void 0 ? void 0 : mods.transform) !== null && _b !== void 0 ? _b : ((v) => v);
        this.enableMod = (_c = mods === null || mods === void 0 ? void 0 : mods.enable) !== null && _c !== void 0 ? _c : (() => true);
        this.forceMod = (_d = mods === null || mods === void 0 ? void 0 : mods.force) !== null && _d !== void 0 ? _d : (() => false);
    }
    /**
     * The default value of this node
     * @param value optional original value
     */
    default(value) {
        return this.defaultMod(value);
    }
    /**
     * Transforms the data model to the final output format
     * @param
     */
    transform(path, value, view) {
        if (!this.enabled(path))
            return undefined;
        if (value === undefined && this.force())
            value = this.default(value);
        return this.transformMod(value);
    }
    /**
     * Determines whether the node should be enabled for this path
     * @param path
     * @param model
     */
    enabled(path, model) {
        if (model)
            path = path.withModel(model);
        return this.enableMod(path.pop());
    }
    force() {
        return this.forceMod();
    }
    /**
     * Validates the model using this schema
     * @param value value to be validated
     */
    validate(path, value, errors) {
        return true;
    }
}
exports.AbstractNode = AbstractNode;
