"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BooleanNode = void 0;
const AbstractNode_1 = require("./AbstractNode");
const Registries_1 = require("../Registries");
/**
 * Boolean node with two buttons for true/false
 */
class BooleanNode extends AbstractNode_1.AbstractNode {
    /**
     * @param mods optional node modifiers
     */
    constructor(mods) {
        super({
            default: () => false,
            ...mods
        });
    }
    render(path, value, view, options) {
        const falseButton = view.registerClick(el => {
            view.model.set(path, !this.force() && value === false ? undefined : false);
        });
        const trueButton = view.registerClick(el => {
            view.model.set(path, !this.force() && value === true ? undefined : true);
        });
        return `<div class="node boolean-node node-header">
      ${(options === null || options === void 0 ? void 0 : options.removeId) ? `<button data-id="${options === null || options === void 0 ? void 0 : options.removeId}"></button>` : ``}
      ${(options === null || options === void 0 ? void 0 : options.hideLabel) ? `` : `<label>${Registries_1.locale(path)}</label>`}
      <button${value === false ? ' class="selected"' : ' '} 
        data-id="${falseButton}">${Registries_1.locale('false')}</button>
      <button${value === true ? ' class="selected"' : ' '} 
        data-id="${trueButton}">${Registries_1.locale('true')}</button>
    </div>`;
    }
    validate(path, value, errors) {
        if (typeof value !== 'boolean' || value === undefined) {
            return errors.add(path, 'error.expected_boolean');
        }
        return true;
    }
}
exports.BooleanNode = BooleanNode;
