"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EnumNode = void 0;
const AbstractNode_1 = require("./AbstractNode");
const Registries_1 = require("../Registries");
/**
 * Enum node that shows a list of options to choose from
 */
let EnumNode = /** @class */ (() => {
    class EnumNode extends AbstractNode_1.AbstractNode {
        /**
         * @param options options to choose from in the select
         * @param mods optional node modifiers or a string to be the default value
         */
        constructor(options, mods) {
            super(typeof mods === 'string' ? {
                default: () => mods,
                force: () => true
            } : mods);
            this.options = options;
        }
        getState(el) {
            return el.querySelector('select').value;
        }
        render(path, value, view, options) {
            const selectId = view.register(el => {
                el.value = value;
                el.addEventListener('change', evt => {
                    view.model.set(path, el.value);
                    evt.stopPropagation();
                });
            });
            return `<div class="node enum-node node-header">
      ${(options === null || options === void 0 ? void 0 : options.removeId) ? `<button class="remove" data-id="${options === null || options === void 0 ? void 0 : options.removeId}"></button>` : ``}
      ${(options === null || options === void 0 ? void 0 : options.hideLabel) ? `` : `<label>${Registries_1.locale(path)}</label>`}
      <select data-id=${selectId}>
        ${this.options.map(o => `<option value="${o}">${Registries_1.locale(path.push(o))}</option>`).join('')}
      </select>
    </div>`;
        }
        renderRaw(path) {
            return `<select>
      ${this.options.map(o => `<option value="${o}">${Registries_1.locale(path.push(o))}</option>`).join('')}
    </select>`;
        }
        validate(path, value, errors) {
            if (typeof value !== 'string') {
                return errors.add(path, 'error.expected_string');
            }
            if (!this.options.includes(value)) {
                return errors.add(path, 'error.invalid_enum_option');
            }
            return true;
        }
    }
    EnumNode.className = 'enum-node';
    return EnumNode;
})();
exports.EnumNode = EnumNode;
