"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ListNode = void 0;
const AbstractNode_1 = require("./AbstractNode");
const Registries_1 = require("../Registries");
/**
 * List node where children can be added and removed from
 */
class ListNode extends AbstractNode_1.AbstractNode {
    /**
     * @param values node used for its children
     * @param mods optional node modifiers
     */
    constructor(values, mods) {
        super({
            default: () => [],
            ...mods
        });
        this.children = values;
    }
    transform(path, value, view) {
        if (!(value instanceof Array))
            return undefined;
        const res = value.map((obj, index) => this.children.transform(path.push(index), obj, view));
        return this.transformMod(res);
    }
    render(path, value, view) {
        value = value || [];
        const button = view.registerClick(el => {
            view.model.set(path, [...value, this.children.default()]);
        });
        return `<div class="node list-node">
      <div class="node-header">
        <label>${Registries_1.locale(path)}</label>
        <button class="add" data-id="${button}"></button>
      </div>
      <div class="node-body">
        ${value.map((obj, index) => {
            return this.renderEntry(path.push(index), obj, view);
        }).join('')}
      </div>
    </div>`;
    }
    renderEntry(path, value, view) {
        const button = view.registerClick(el => {
            view.model.set(path, undefined);
        });
        return `<div class="node-entry">
      ${this.children.render(path, value, view, { hideLabel: true, removeId: button, removeLabel: Registries_1.locale(path.push('entry')) })}
    </div>`;
    }
    validate(path, value, errors) {
        if (!(value instanceof Array)) {
            return errors.add(path, 'error.expected_list');
        }
        let allValid = true;
        value.forEach((obj, index) => {
            if (this.children.validate(path.push(index), obj, errors)) {
                allValid = false;
            }
        });
        return allValid;
    }
}
exports.ListNode = ListNode;
