"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MapNode = void 0;
const AbstractNode_1 = require("./AbstractNode");
const Registries_1 = require("../Registries");
/**
 * Map nodes similar to list nodes, but a string key is required to add children
 */
class MapNode extends AbstractNode_1.AbstractNode {
    /**
     *
     * @param keys node used for the string key
     * @param values node used for the map values
     * @param mods optional node modifiers
     */
    constructor(keys, values, mods) {
        super({
            default: () => ({}),
            ...mods
        });
        this.keys = keys;
        this.values = values;
    }
    transform(path, value, view) {
        if (value === undefined)
            return undefined;
        let res = {};
        Object.keys(value).forEach(f => res[f] = this.values.transform(path.push(f), value[f], view));
        return this.transformMod(res);
    }
    render(path, value, view) {
        value = value !== null && value !== void 0 ? value : [];
        const button = view.registerClick(el => {
            const key = this.keys.getState(el.parentElement);
            view.model.set(path.push(key), this.values.default());
        });
        return `<div class="node map-node">
      <div class="node-header">
        <label>${Registries_1.locale(path)}</label>
        ${this.keys.renderRaw(path)}
        <button class="add" data-id="${button}"></button>
      </div>
      <div class="node-body">
        ${Object.keys(value).map(key => {
            return this.renderEntry(path.push(key), value[key], view);
        }).join('')}
      </div>
    </div>`;
    }
    renderEntry(path, value, view) {
        const button = view.registerClick(el => {
            view.model.set(path, undefined);
        });
        return `<div class="node-entry">
      ${this.values.render(path, value, view, { removeId: button })}
    </div>`;
    }
    validate(path, value, errors) {
        if (value === null || typeof value !== 'object') {
            return errors.add(path, 'error.expected_object');
        }
        let allValid = true;
        Object.keys(value).forEach(k => {
            if (!this.keys.validate(path, k, errors)) {
                allValid = false;
            }
            if (!this.values.validate(path.push(k), value[k], errors)) {
                allValid = false;
            }
        });
        return allValid;
    }
}
exports.MapNode = MapNode;
