"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NumberNode = void 0;
const AbstractNode_1 = require("./AbstractNode");
const Registries_1 = require("../Registries");
/**
 * Configurable number node with one text field
 */
class NumberNode extends AbstractNode_1.AbstractNode {
    /**
     * @param mods optional node modifiers
     */
    constructor(mods) {
        var _a, _b, _c;
        super({
            default: () => 0,
            ...mods
        });
        this.integer = (_a = mods === null || mods === void 0 ? void 0 : mods.integer) !== null && _a !== void 0 ? _a : false;
        this.min = (_b = mods === null || mods === void 0 ? void 0 : mods.min) !== null && _b !== void 0 ? _b : -Infinity;
        this.max = (_c = mods === null || mods === void 0 ? void 0 : mods.max) !== null && _c !== void 0 ? _c : Infinity;
    }
    getState(el) {
        const value = el.value;
        const parsed = this.integer ? parseInt(value) : parseFloat(value);
        if (parsed < this.min)
            return this.min;
        if (parsed > this.max)
            return this.max;
        return parsed;
    }
    render(path, value, view, options) {
        const id = view.registerChange(el => {
            view.model.set(path, this.getState(el));
        });
        return `<div class="node number-node node-header">
      ${(options === null || options === void 0 ? void 0 : options.removeId) ? `<button class="remove" data-id="${options === null || options === void 0 ? void 0 : options.removeId}"></button>` : ``}
      ${(options === null || options === void 0 ? void 0 : options.hideLabel) ? `` : `<label>${Registries_1.locale(path)}</label>`}
      <input data-id="${id}" value="${value !== null && value !== void 0 ? value : ''}">
    </div>`;
    }
    validate(path, value, errors) {
        if (typeof value !== 'number') {
            return errors.add(path, 'error.expected_number');
        }
        if (this.integer && !Number.isInteger(value)) {
            return errors.add(path, 'error.expected_integer');
        }
        if (value < this.min) {
            return errors.add(path, 'error.invalid_range.smaller', value, this.min);
        }
        if (value > this.max) {
            return errors.add(path, 'error.invalid_range.larger', value, this.max);
        }
        return true;
    }
}
exports.NumberNode = NumberNode;
