import { NodeMods, INode, NodeChildren, AbstractNode, RenderOptions } from './AbstractNode';
import { Path } from '../model/Path';
import { TreeView } from '../view/TreeView';
import { SourceView } from '../view/SourceView';
import { DataModel } from '../model/DataModel';
import { Errors } from '../model/Errors';
export declare const Switch: unique symbol;
export declare const Case: unique symbol;
export declare type NestedNodeChildren = {
    [name: string]: NodeChildren;
};
export declare type IObject = {
    [name: string]: any;
};
export declare type FilteredChildren = {
    [name: string]: INode<any>;
    /** The field to filter on */
    [Switch]?: (path: Path) => any;
    /** Map of filter values to node fields */
    [Case]?: NestedNodeChildren;
};
export interface ObjectNodeMods extends NodeMods<object> {
    /** Whether the object can be collapsed. Necessary when recursively nesting. */
    collapse?: boolean;
    category?: string;
}
/**
 * Object node containing fields with different types.
 * Has the ability to filter fields based on a switch field.
 */
export declare class ObjectNode extends AbstractNode<IObject> {
    fields: NodeChildren;
    cases: NestedNodeChildren;
    filter?: (path: Path) => any;
    collapse?: boolean;
    category?: string;
    /**
     * @param fields children containing the optional switch and case
     * @param mods optional node modifiers
     */
    constructor(fields: FilteredChildren, mods?: ObjectNodeMods);
    transform(path: Path, value: IObject, view: SourceView): any;
    render(path: Path, value: IObject, view: TreeView, options?: RenderOptions): string;
    renderFields(path: Path, value: IObject, view: TreeView): string;
    getActiveFields(path: Path, model: DataModel): NodeChildren;
    validate(path: Path, value: any, errors: Errors): boolean;
}
