"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StringNode = void 0;
const AbstractNode_1 = require("./AbstractNode");
const Registries_1 = require("../Registries");
/**
 * Simple string node with one text field
 */
class StringNode extends AbstractNode_1.AbstractNode {
    /**
     * @param mods optional node modifiers
     */
    constructor(mods) {
        var _a;
        super(mods);
        this.allowEmpty = (_a = mods === null || mods === void 0 ? void 0 : mods.allowEmpty) !== null && _a !== void 0 ? _a : false;
    }
    getState(el) {
        return el.querySelector('input').value;
    }
    render(path, value, view, options) {
        const id = view.registerChange(el => {
            const value = el.value;
            view.model.set(path, this.allowEmpty || value !== '' ? value : undefined);
        });
        return `<div class="node string-node node-header">
      ${(options === null || options === void 0 ? void 0 : options.removeId) ? `<button class="remove" data-id="${options === null || options === void 0 ? void 0 : options.removeId}"></button>` : ``}
      ${(options === null || options === void 0 ? void 0 : options.hideLabel) ? `` : `<label>${Registries_1.locale(path)}</label>`}
      <input data-id="${id}" value="${value !== null && value !== void 0 ? value : ''}">
    </div>`;
    }
    renderRaw() {
        return `<input>`;
    }
    validate(path, value, errors) {
        if (typeof value !== 'string') {
            return errors.add(path, 'error.expected_string');
        }
        return true;
    }
}
exports.StringNode = StringNode;
